#
# spec file for package fusion-icon
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fusion-icon
Version:        0.2.4
Release:        1.36
Summary:        Tray icon to manage Compiz
License:        GPL-2.0+
Group:          System/GUI/Other
Url:            https://github.com/compiz-reloaded/fusion-icon
Source:         https://github.com/compiz-reloaded/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        %{name}.1
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3
BuildRequires:  update-desktop-files
Requires:       Mesa-demo-x
Requires:       python3-compizconfig
Requires:       python3-gobject
Requires:       python3-qt5
Requires:       xvinfo
Recommends:     compiz-gnome < 0.9
Suggests:       compizconfig-settings-manager < 0.9
BuildArch:      noarch
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%endif

%description
This package provides a tray icon that allows you to easily enable,
disable and restart Compiz, and change the currently used window
manager and/or window decorator.

%prep
%setup -q
cp -f %{SOURCE1} %{name}.1

%build
python3 setup.py build \
  --with-qt=5.0 --with-gtk=3.0

%install
python3 setup.py install \
  --root=%{buildroot} \
  --prefix=%{_prefix}

mv %{buildroot}%{_datadir}/{metainfo,appdata}/
install -Dpm 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
%suse_update_desktop_file -r %{name} Utility DesktopUtility
%fdupes %{buildroot}%{python_sitelib}/

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING NEWS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{python3_sitelib}/FusionIcon/
%{python3_sitelib}/fusion_icon-*
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Sat Jun 10 2017 sor.alexei@meowr.ru
- Update to version 0.2.4:
  * Make the application ID for SNI the same as in AppIndicator in
    Qt5: "Fusion Icon". Can affect the icon ordering.
  * Stop using fusion-icon-panel in the Qt frontend.
    The icon is expected to sometimes be symbolic.
    Hence explicit lookup for it can cause problems.
  * Implement left-click action with SNI on Qt5.
  * Open menu on "secondary action" in GTK+3.
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.2.3:
  * Fix fail to fallback from GTK+ if dependencies are not met.
  * Add Python3 support.
  * Use /usr/local as a default prefix path.
- Switch to Python3.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 0.2.2:
  * Fix a crash in some cases caused by an error in DE detection.
  * Acknowledge fusion-icon-panel icon in Qt backend.
  * Some minor fixes.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to 0.2.1:
  * Add left click action on Qt backend.
  * Fix an icon of Emerald Theme Manager 0.8.12.1 on Gtk backend.
* Sat Feb 13 2016 sor.alexei@meowr.ru
- Update to 0.2.0:
  * Restore Qt backend with fixes, menu entry icons and Qt5 support
    (Qt version is selectable via --with-qt=4.0/5.0 setup.py arg).
  * Restore Gtk2 support (selectable via --with-gtk=2.0/3.0 setup.py
    argument).
  * Gtk backend is the default one, except for KDE and LXQt where
    Qt is defaulted instead.
  * Note that one can select desired backend manually with
    $FUSION_ICON_BACKEND environment variable.
  * Replace icons for Window Manager and Window Decorator entries
    with icons from icon themes (were from deprecated GtkStock).
  * Drop mate-window-decorator.py hacks as script itself was
    removed.
- Add python-qt5 dependency for Qt backend.
* Sun Dec 20 2015 sor.alexei@meowr.ru
- Update to 0.1.2:
  * Create the tray icon using appindicators (SNI-tray).
  * Actualise desktop environments detection.
  * Use mate-window-decorator instead of setting Marco theme
    manually.
  * Add partial Compiz 0.9.x support.
  * Make it possible to set fusion-icon as a WM in MATE.
- Remove fusion-icon-suse.patch and fusion-icon-appindicator.patch:
  fixed upstream.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.1.1:
  * Add Gtk3 backend.
  * Drop Gtk2 and Qt4 backends.
  * If no options are available, do not show the menu.
  * Add Marco support.
- Add missing dependencies.
- Add fusion-icon-suse.patch: use openSUSE scripts.
- Add fusion-icon-appindicator.patch: use AppIndicator (SNI).
- Drop fusion-icon-0.1-compiz09_decor.patch,
  fusion-icon-0.1-compiz09_desktop_hints.patch,
  fusion-icon-0.1-compiz09_screen.patch: Compiz 0.8.x branch.
- Spec cleanup.
* Wed Apr 13 2011 nmarques@opensuse.org
- Initial package for openSUSE, version 0.1
  + Add fusion-icon-0.1-compiz09_decor.patch, 'decoration' plugin
    changed name in 0.9;
  + Add fusion-icon-0.1-compiz09_desktop_hints.patch, option no
    longer exists in 0.9;
  + Add fusion-icon-0.1-compiz09_screen.patch, 'Display' plugin
    changed name to 'Screen' in 0.9.
- Added man1 page, taken from Ubuntu.
